#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""

   Copyright 2020 GRIDmeter™ contributors

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

"""
__title__ = "GRIDmeter™"
__description__ = "Tools for stratified sampling for comparison groups"
__url__ = "http://github.com/recurve-methods/comparison_groups"
__version__ = "1.1.0"
__author__ = "Recurve Analytics, Inc"
__author_email__ = "admin@openee.io"
__license__ =  "Apache 2.0" 
__copyright__ = "Copyright 2020 Recurve Analytics, Inc."
